@@ -1,33 +1,36 @@
-//////////////////////////////////////////////////////////////////////////////
-//
-//    IMAGEPREVIEW.CPP
-//
-//    Copyright (C) 2003 Gilles CAULIER <caulier dot gilles at gmail dot com>
-//
-//    This program is free software; you can redistribute it and/or modify
-//    it under the terms of the GNU General Public License as published by
-//    the Free Software Foundation; either version 2 of the License, or
-//    (at your option) any later version.
-//
-//    This program is distributed in the hope that it will be useful,
-//    but WITHOUT ANY WARRANTY; without even the implied warranty of
-//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//    GNU General Public License for more details.
-//
-//    You should have received a copy of the GNU General Public License
-//    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
-//
-//////////////////////////////////////////////////////////////////////////////
-
+/* ============================================================
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-10-01
+ * Description : a kipi plugin to batch process images
+ *
+ * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * This program is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU General
+ * Public License as published by the Free Software Foundation;
+ * either version 2, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * ============================================================ */
+ 
 // C Ansi includes
 
 extern "C"
 {
 #include <unistd.h>
-#include <stdlib.h>
 }
 
+// C++ includes.
+
+#include <cstdlib>
+
 // Qt includes
 
 #include <qpixmap.h>
@@ -74,8 +77,6 @@ namespace KIPIBatchProcessImagesPlugin
 
 int INIT_ZOOM_FACTOR;
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 ImagePreview::ImagePreview(const QString &fileOrig, const QString &fileDest, const QString &tmpPath,
                            bool cropActionOrig, bool cropActionDest, const QString &EffectName,
                            const QString &FileName, QWidget *parent)
@@ -85,7 +86,7 @@ ImagePreview::ImagePreview(const QString &fileOrig, const QString &fileDest, con
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Batch process images"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("An interface to preview the \"Batch Process Images\" "
                                                      "Kipi plugin.\n"
@@ -99,7 +100,7 @@ ImagePreview::ImagePreview(const QString &fileOrig, const QString &fileDest, con
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Kipi Plugins Handbooks"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbooks"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     //---------------------------------------------
@@ -117,30 +118,6 @@ ImagePreview::ImagePreview(const QString &fileOrig, const QString &fileDest, con
 
     //---------------------------------------------
 
-    QFrame *headerFrame = new QFrame( box );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Batch Process Preview (%1 - %2)")
-                                     .arg(EffectName).arg(FileName), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    ml->addWidget( headerFrame );
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
-    //---------------------------------------------
-
     QHBoxLayout* h1 = new QHBoxLayout( ml );
     QVBoxLayout* v1 = new QVBoxLayout( h1 );
     h1->addSpacing( 5 );
@@ -189,26 +166,16 @@ ImagePreview::ImagePreview(const QString &fileOrig, const QString &fileDest, con
     m_previewDest->setImage(fileDest, tmpPath);
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 ImagePreview::~ImagePreview()
 {
     delete m_about;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
 void ImagePreview::slotHelp( void )
 {
-    KApplication::kApplication()->invokeHelp("",
-                                             "kipi-plugins");
+    KApplication::kApplication()->invokeHelp("", "kipi-plugins");
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
 void ImagePreview::slotWheelChanged( int delta )
 {
     if ( delta > 0 )
@@ -219,9 +186,6 @@ void ImagePreview::slotWheelChanged( int delta )
     slotZoomFactorValueChanged( ZoomFactorSlider->value() );
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
 void ImagePreview::slotZoomFactorValueChanged( int ZoomFactorValue )
 {
     LCDZoomFactorValue->display( QString::number(ZoomFactorValue * 5) );
@@ -230,9 +194,6 @@ void ImagePreview::slotZoomFactorValueChanged( int ZoomFactorValue )
     m_previewDest->resizeImage( ZoomFactorValue * 5 );
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 PixmapView::PixmapView(bool cropAction, QWidget *parent, const char *name)
            : QScrollView(parent, name)
 {
@@ -250,17 +211,11 @@ PixmapView::PixmapView(bool cropAction, QWidget *parent, const char *name)
                    + "handcursor.png" );
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 PixmapView::~PixmapView()
 {
     if(m_pix) delete m_pix;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void PixmapView::setImage(const QString &ImagePath, const QString &tmpPath)
 {
 
@@ -286,9 +241,7 @@ void PixmapView::setImage(const QString &ImagePath, const QString &tmpPath)
        }
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
-void PixmapView::PreviewCal(const QString &ImagePath, const QString &tmpPath)
+void PixmapView::PreviewCal(const QString &ImagePath, const QString &/*tmpPath*/)
 {
     m_pix = new QPixmap(300, 300);
     QPainter p;
@@ -324,26 +277,19 @@ void PixmapView::PreviewCal(const QString &ImagePath, const QString &tmpPath)
             this, SLOT(slotPreviewReadStd(KProcess*, char*, int)));
 
     bool result = m_PreviewProc->start(KProcess::NotifyOnExit, KProcess::All);
-
     if(!result)
-       {
-       KMessageBox::error(this, i18n("Cannot start 'convert' program from 'ImageMagick' package;\n"
-                                     "please check your installation."));
-       return;
-       }
+    {
+        KMessageBox::error(this, i18n("Cannot start 'convert' program from 'ImageMagick' package;\n"
+                                      "please check your installation."));
+        return;
+    }
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
-void PixmapView::slotPreviewReadStd(KProcess* proc, char *buffer, int buflen)
+void PixmapView::slotPreviewReadStd(KProcess* /*proc*/, char *buffer, int buflen)
 {
     m_previewOutput.append( QString::fromLocal8Bit(buffer, buflen) );
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void PixmapView::PreviewProcessDone(KProcess* proc)
 {
     int ValRet = proc->exitStatus();
@@ -384,10 +330,6 @@ void PixmapView::PreviewProcessDone(KProcess* proc)
        }
 }
 
-
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void PixmapView::resizeImage(int ZoomFactor)
 {
     if ( m_validPreview == false) return;
@@ -401,26 +343,17 @@ void PixmapView::resizeImage(int ZoomFactor)
     repaintContents(false);
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void PixmapView::drawContents(QPainter *p, int x, int y, int w, int h)
 {
     if(!m_pix) return;
     else p->drawPixmap(x, y, *m_pix, x, y, w, h);
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void PixmapView::contentsWheelEvent( QWheelEvent * e )
 {
     emit wheelEvent(e->delta());
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void PixmapView::contentsMousePressEvent ( QMouseEvent * e )
 {
     if ( e->button() == Qt::LeftButton )
@@ -431,17 +364,11 @@ void PixmapView::contentsMousePressEvent ( QMouseEvent * e )
        }
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
-void PixmapView::contentsMouseReleaseEvent ( QMouseEvent * e )
+void PixmapView::contentsMouseReleaseEvent ( QMouseEvent * /*e*/ )
 {
     setCursor ( KCursor::arrowCursor() );
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void PixmapView::contentsMouseMoveEvent( QMouseEvent * e )
 {
      if ( e->state() == Qt::LeftButton )
@@ -457,4 +384,3 @@ void PixmapView::contentsMouseMoveEvent( QMouseEvent * e )
 }
 
 }  // NameSpace KIPIBatchProcessImagesPlugin
-
