@@ -2,7 +2,7 @@
  * File  : gallerywidget.h
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2004-12-01
- * Copyright 2004 by Renchi Raju
+ * Copyright 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,6 +49,8 @@ private:
     KHTMLPart*    m_photoView;
     QPushButton*  m_newAlbumBtn;
     QPushButton*  m_addPhotoBtn;
+    QCheckBox*    m_captTitleCheckBox;
+    QCheckBox*    m_captDescrCheckBox;
     QCheckBox*    m_resizeCheckBox;
     QSpinBox*     m_dimensionSpinBox;
 
