@@ -1,19 +1,21 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
- * Date   : 2006-09-19
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2006-09-19
  * Description : Autodetect gpsbabel binary program and version
  *
- * Copyright 2006 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- * 
+ * either version 2, or (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
@@ -23,11 +25,9 @@
 #include <kapplication.h>
 #include <kprocess.h>
 #include <kmessagebox.h>
-#include <kapplication.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <kdebug.h>
-#include <kaboutdata.h>
 
 // Local includes
 
@@ -53,7 +53,7 @@ public:
 };
 
 GPSBabelBinary::GPSBabelBinary()
-           : QObject()
+              : QObject()
 {
     d = new GPSBabelBinaryPriv;
     checkSystem();
@@ -78,7 +78,7 @@ void GPSBabelBinary::checkSystem()
 
 void GPSBabelBinary::slotReadStdoutFromGPSBabel(KProcess*, char* buffer, int buflen)
 {
-    // The dcraw output look like this : GPSBabel Version 1.2.5
+    // The gpsbabel output look like this : GPSBabel Version 1.2.5
     QString headerStarts("GPSBabel Version ");
 
     QString stdOut    = QString::fromLocal8Bit(buffer, buflen);
@@ -123,4 +123,3 @@ QString GPSBabelBinary::minimalVersion() const
 }
 
 }  // namespace KIPIGPSSyncPlugin
-
