@@ -1,21 +1,23 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
- * Date   : 2006-09-19
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2006-09-19
  * Description : GPS file list view item.
- * 
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- * 
+ * either version 2, or (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * ============================================================ */
 
 #ifndef GPSLISTVIEWITEM_H
@@ -39,47 +41,38 @@ class QPainter;
 class QColorGroup;
 class QPixmap;
 
-class KFileItem;
-
 namespace KIPIGPSSyncPlugin
 {
 class GPSListViewItemPriv;
 
-class GPSListViewItem : public QObject, public KListViewItem
+class GPSListViewItem : public KListViewItem
 {
 
-Q_OBJECT
-
 public:
 
     GPSListViewItem(KListView *view, QListViewItem *after, const KURL& url);
     ~GPSListViewItem();
 
-    void setGPSInfo(GPSDataContainer gpsData, bool dirty=true, bool addedManually=false);
-    GPSDataContainer getGPSInfo();
+    void setGPSInfo(const GPSDataContainer& gpsData, bool dirty=true, bool addedManually=false);
+    GPSDataContainer GPSInfo() const;
     void eraseGPSInfo();
 
-    void setDateTime(QDateTime date);
-    QDateTime getDateTime();
+    void setDateTime(const QDateTime &date);
+    QDateTime dateTime() const;
 
     void setEnabled(bool e);
     bool isEnabled();
     bool isDirty();
     bool isInterpolated();
     bool hasGPSInfo();
-    bool isReadOnly();
 
-    KURL getUrl();
+    KURL url();
     void writeGPSInfoToFile();
-        
+
 protected:
 
     void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment);
 
-private slots:
-
-    void slotGotThumbnail(const KFileItem*, const QPixmap&);
-
 private: 
 
     GPSListViewItemPriv *d;
