@@ -1,20 +1,22 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
- * Date   : 2006-05-16
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2006-05-16
  * Description : a plugin to synchronize pictures with 
  *               a GPS device.
  *
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
@@ -33,6 +35,8 @@
 
 class QListViewItem;
 
+class KFileItem;
+
 namespace KIPIGPSSyncPlugin
 {
 
@@ -64,6 +68,7 @@ protected slots:
 
 private slots:
 
+    void slotGotThumbnail(const KFileItem*, const QPixmap&);
     void slotLoadGPXFile(); 
 
 private:
@@ -80,4 +85,3 @@ private:
 }  // NameSpace KIPIGPSSyncPlugin
 
 #endif /* GPSSYNCDIALOG_H */
-
