@@ -1,7 +1,7 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
 A KIPI plugin to generate HTML image galleries
-Copyright 2006 Aurelien Gateau
+Copyright 2006 by Aurelien Gateau <aurelien dot gateau at free.fr>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
 
 */
 #ifndef WIZARD_H
@@ -24,9 +24,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // KDE
 #include <kwizard.h>
 
-//Local includes
-#include "kpaboutdata.h"
-
 namespace KIPI {
 class Interface;
 }
@@ -35,6 +32,9 @@ namespace KIPIHTMLExport {
 
 class GalleryInfo;
 
+/**
+ * The wizard used by the user to select the various settings.
+ */
 class Wizard : public KWizard {
 Q_OBJECT
 public:
@@ -45,15 +45,13 @@ protected slots:
 	virtual void accept();
 
 private slots:
-    void slotHelp();
+	void showHelp();
 	void updateFinishButton();
 	void slotThemeSelectionChanged();
 
 private:
 	struct Private;
 	Private* d;
-
-        KIPIPlugins::KPAboutData    *m_about; 
 };
 
 
