@@ -1,18 +1,23 @@
 /* ============================================================
- * Authors: Ralf Hoelzer <kde at ralfhoelzer.com>
- *          Marcel Wiesweg <marcel.wiesweg@gmx.de>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2004-06-08
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-06-08
+ * Description : Loss less JPEG files transformations.
  * 
- * Copyright 2004 by  Ralf Hoelzer
- * Copyright 2004-2005 by Marcel Wiesweg
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2004      by  Ralf Hoelzer <kde at ralfhoelzer.com>
+ * Copyright (C) 2004-2005 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * NOTE: Do not use kdDebug() in this implementation because 
+ *       it will be multithreaded. Use qDebug() instead. 
+ *       See B.K.O #133026 for details.
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -44,7 +49,6 @@ extern "C"
 
 // KDE includes.
 
-#include <kdebug.h>
 #include <klocale.h>
 #include <ktempfile.h>
 
@@ -57,14 +61,14 @@ extern "C"
 namespace KIPIJPEGLossLessPlugin
 {
 
-Matrix Matrix::none                   ( 1,  0,  0,  1);
-Matrix Matrix::rotate90               ( 0, -1,  1,  0);
-Matrix Matrix::rotate180              (-1,  0,  0, -1);
-Matrix Matrix::rotate270              ( 0,  1, -1,  0);
-Matrix Matrix::flipHorizontal         (-1,  0,  0,  1);
-Matrix Matrix::flipVertical           ( 1,  0,  0, -1);
-Matrix Matrix::rotate90flipHorizontal ( 0,  1,  1,  0);
-Matrix Matrix::rotate90flipVertical   ( 0, -1, -1,  0);
+const Matrix Matrix::none                   ( 1,  0,  0,  1);
+const Matrix Matrix::rotate90               ( 0, -1,  1,  0);
+const Matrix Matrix::rotate180              (-1,  0,  0, -1);
+const Matrix Matrix::rotate270              ( 0,  1, -1,  0);
+const Matrix Matrix::flipHorizontal         (-1,  0,  0,  1);
+const Matrix Matrix::flipVertical           ( 1,  0,  0, -1);
+const Matrix Matrix::rotate90flipHorizontal ( 0,  1,  1,  0);
+const Matrix Matrix::rotate90flipVertical   ( 0, -1, -1,  0);
 
 
 // To manage Errors/Warnings handling provide by libjpeg
@@ -88,7 +92,7 @@ static void jpegtransform_jpeg_error_exit(j_common_ptr cinfo)
     (*cinfo->err->format_message)(cinfo, buffer);
 
 #ifdef ENABLE_DEBUG_MESSAGES
-    kdDebug() << k_funcinfo << buffer << endl;
+    qDebug("%s", buffer)
 #endif
 
     longjmp(myerr->setjmp_buffer, 1);
@@ -101,7 +105,7 @@ static void jpegtransform_jpeg_emit_message(j_common_ptr cinfo, int msg_level)
     (*cinfo->err->format_message)(cinfo, buffer);
 
 #ifdef ENABLE_DEBUG_MESSAGES
-    kdDebug() << k_funcinfo << buffer << " (" << msg_level << ")" << endl;
+    qDebug("%s (%i)", buffer, msg_level);
 #endif
 }
 
@@ -111,7 +115,7 @@ static void jpegtransform_jpeg_output_message(j_common_ptr cinfo)
     (*cinfo->err->format_message)(cinfo, buffer);
 
 #ifdef ENABLE_DEBUG_MESSAGES
-    kdDebug() << k_funcinfo << buffer << endl;
+    qDebug("%s", buffer)
 #endif
 }
 
@@ -133,8 +137,8 @@ bool transformJPEG(const QString& src, const QString& destGiven,
     jvirt_barray_ptr * src_coef_arrays;
     jvirt_barray_ptr * dst_coef_arrays;
 
-    Matrix exifAction, action;
-    JXFORM_CODE flip,rotate;
+    Matrix      exifAction, action;
+    JXFORM_CODE flip, rotate;
 
     // Initialize the JPEG decompression object with default error handling
     srcinfo.err                 = jpeg_std_error(&jsrcerr);
@@ -154,7 +158,7 @@ bool transformJPEG(const QString& src, const QString& destGiven,
     input_file = fopen(QFile::encodeName(src), "rb");
     if (!input_file)
     {
-        kdError() << "ImageRotate/ImageFlip: Error in opening input file" << endl;
+        qDebug("ImageRotate/ImageFlip: Error in opening input file");
         err = i18n("Error in opening input file");
         return false;
     }
@@ -163,7 +167,7 @@ bool transformJPEG(const QString& src, const QString& destGiven,
     if (!output_file)
     {
         fclose(input_file);
-        kdError() << "ImageRotate/ImageFlip: Error in opening output file" << endl;
+        qDebug("ImageRotate/ImageFlip: Error in opening output file");
         err = i18n("Error in opening output file");
         return false;
     }
@@ -186,7 +190,7 @@ bool transformJPEG(const QString& src, const QString& destGiven,
     (void) jpeg_read_header(&srcinfo, true);
 
     // Get Exif orientation action to do.
-    KIPIPlugins::Exiv2Iface exiv2Iface;
+    KExiv2Iface::KExiv2 exiv2Iface;
     exiv2Iface.load(src);
     getExifAction(exifAction, exiv2Iface.getImageOrientation());
 
@@ -196,7 +200,15 @@ bool transformJPEG(const QString& src, const QString& destGiven,
 
     // Convert action into flip+rotate action
     convertTransform(action, flip, rotate);
-    kdDebug() << "Transforming with option " << flip << " " << rotate <<endl;
+    qDebug("Transforming with option %i %i", flip, rotate);
+    if (flip == JXFORM_NONE && rotate == JXFORM_NONE)
+    {
+        err = "nothing to do"; // magic string
+        fclose(output_file);
+        fclose(input_file);
+        return false;
+    }
+
     bool twoPass = (flip != JXFORM_NONE);
 
     // If twoPass is true, we need another file (src -> tempFile -> destGiven)
@@ -211,7 +223,7 @@ bool transformJPEG(const QString& src, const QString& destGiven,
     if (!output_file)
     {
         fclose(input_file);
-        kdError() << "ImageRotate/ImageFlip: Error in opening output file" << endl;
+        qDebug("ImageRotate/ImageFlip: Error in opening output file");
         err = i18n("Error in opening output file");
         return false;
     }
@@ -268,7 +280,7 @@ bool transformJPEG(const QString& src, const QString& destGiven,
         input_file = fopen(QFile::encodeName(dest), "rb");
         if (!input_file)
         {
-            kdError() << "ImageRotate/ImageFlip: Error in opening input file" << endl;
+            qDebug("ImageRotate/ImageFlip: Error in opening input file");
             err = i18n("Error in opening input file");
             return false;
         }
@@ -277,7 +289,7 @@ bool transformJPEG(const QString& src, const QString& destGiven,
         if (!output_file)
         {
             fclose(input_file);
-            kdError() << "ImageRotate/ImageFlip: Error in opening output file" << endl;
+            qDebug("ImageRotate/ImageFlip: Error in opening output file");
             err = i18n("Error in opening output file");
             return false;
         }
@@ -334,8 +346,8 @@ bool transformJPEG(const QString& src, const QString& destGiven,
     QImage img(destGiven);
     QImage exifThumbnail = img.scale(160, 120, QImage::ScaleMin);
     exiv2Iface.load(destGiven);
-    exiv2Iface.setImageOrientation(KIPIPlugins::Exiv2Iface::ORIENTATION_NORMAL);
-    exiv2Iface.setImageProgramId(QString("Kipi JPEGLossLess"), QString(kipiplugins_version));
+    exiv2Iface.setImageOrientation(KExiv2Iface::KExiv2::ORIENTATION_NORMAL);
+    exiv2Iface.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
     exiv2Iface.setImageDimensions(img.size());
     exiv2Iface.setExifThumbnail(exifThumbnail);
     exiv2Iface.save(destGiven);
@@ -385,42 +397,42 @@ void convertTransform(Matrix &action, JXFORM_CODE &flip, JXFORM_CODE &rotate)
     }
 }
 
-void getExifAction(Matrix &action, KIPIPlugins::Exiv2Iface::ImageOrientation exifOrientation) 
+void getExifAction(Matrix &action, KExiv2Iface::KExiv2::ImageOrientation exifOrientation) 
 {
     switch (exifOrientation) 
     {
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_NORMAL:
+        case KExiv2Iface::KExiv2::ORIENTATION_NORMAL:
             break;
 
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_HFLIP:
+        case KExiv2Iface::KExiv2::ORIENTATION_HFLIP:
             action*=Matrix::flipHorizontal;
             break;
 
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_ROT_180:
+        case KExiv2Iface::KExiv2::ORIENTATION_ROT_180:
             action*=Matrix::rotate180;
             break;
 
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_VFLIP:
+        case KExiv2Iface::KExiv2::ORIENTATION_VFLIP:
             action*=Matrix::flipVertical;
             break;
 
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_ROT_90_HFLIP:
+        case KExiv2Iface::KExiv2::ORIENTATION_ROT_90_HFLIP:
             action*=Matrix::rotate90flipHorizontal;
             break;
 
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_ROT_90:
+        case KExiv2Iface::KExiv2::ORIENTATION_ROT_90:
             action*=Matrix::rotate90;
             break;
 
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_ROT_90_VFLIP:
+        case KExiv2Iface::KExiv2::ORIENTATION_ROT_90_VFLIP:
             action*=Matrix::rotate90flipVertical;
             break;
 
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_ROT_270:
+        case KExiv2Iface::KExiv2::ORIENTATION_ROT_270:
             action*=Matrix::rotate270;
             break;
 
-        case KIPIPlugins::Exiv2Iface::ORIENTATION_UNSPECIFIED:
+        case KExiv2Iface::KExiv2::ORIENTATION_UNSPECIFIED:
             action*=Matrix::none;
             break;
     }
