@@ -45,6 +45,7 @@
 
 // Local includes.
 
+#include "pluginsversion.h"
 #include "kpaboutdata.h"
 #include "setupcamera.h"
 #include "cameraselection.h"
@@ -62,7 +63,7 @@ SetupCamera::SetupCamera(QWidget* parent, const char* name)
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("KameraKlient"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("An Digital camera interface Kipi plugin"),
                                            "(c) 2003-2004, Renchi Raju\n"
@@ -77,7 +78,7 @@ SetupCamera::SetupCamera(QWidget* parent, const char* name)
     helpButton_ = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("KameraKlient Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     helpButton_->setPopup( helpMenu->menu() );
         
     setWFlags(Qt::WDestructiveClose);
@@ -85,29 +86,6 @@ SetupCamera::SetupCamera(QWidget* parent, const char* name)
     setMainWidget(page);
     QVBoxLayout* vbox = new QVBoxLayout(page, 5, 5); 
         
-    //---------------------------------------------
-   
-    QFrame *headerFrame = new QFrame( page );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Setup Cameras"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    vbox->addWidget( headerFrame );
-    
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-    
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
     //---------------------------------------------
         
     QGroupBox* groupBox = new QGroupBox(page, "groupBox");
