@@ -1,15 +1,17 @@
 /* ============================================================
- * Authors     : Gilles Caulier
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
  * Date        : 2006-10-12
  * Description : IPTC date and time settings page.
- * 
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -111,7 +113,7 @@ IPTCDateTime::IPTCDateTime(QWidget* parent)
     d->timeCreatedCheck  = new QCheckBox(i18n("Creation time"), parent);
     d->dateCreatedSel    = new KDateWidget(parent);
     d->timeCreatedSel    = new KTimeWidget(parent);
-    d->syncHOSTDateCheck = new QCheckBox(i18n("Sync creation date hosted by %1")
+    d->syncHOSTDateCheck = new QCheckBox(i18n("Sync creation date entered through %1")
                                               .arg(KApplication::kApplication()->aboutData()->appName()), 
                                               parent);
     d->syncEXIFDateCheck = new QCheckBox(i18n("Sync EXIF creation date"), parent);
