@@ -1,21 +1,23 @@
 /* ============================================================
- * Authors     : Caulier Gilles 
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
  * Date        : 2006-10-12
  * Description : a dialog to edit IPTC metadata
- * 
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // Qt includes.
@@ -70,25 +72,27 @@ public:
 
     IPTCEditDialogDialogPrivate()
     {
-        modified      = false;
-        isReadOnly    = false;
-        page_caption  = 0;
-        page_datetime = 0;
-        page_subjects = 0;
-        page_keywords = 0;
-        page_credits  = 0;
-        page_status   = 0;
-        page_origin   = 0;
+        modified        = false;
+        isReadOnly      = false;
+        page_caption    = 0;
+        page_datetime   = 0;
+        page_subjects   = 0;
+        page_keywords   = 0;
+        page_categories = 0;
+        page_credits    = 0;
+        page_status     = 0;
+        page_origin     = 0;
 
-        about         = 0;
+        about           = 0;
 
-        captionPage   = 0;
-        datetimePage  = 0;
-        subjectsPage  = 0;
-        keywordsPage  = 0;
-        creditsPage   = 0;
-        statusPage    = 0;
-        originPage    = 0;
+        captionPage     = 0;
+        datetimePage    = 0;
+        subjectsPage    = 0;
+        keywordsPage    = 0;
+        categoriesPage  = 0;
+        creditsPage     = 0;
+        statusPage      = 0;
+        originPage      = 0;
     }
 
     bool                      modified;
@@ -175,17 +179,17 @@ IPTCEditDialog::IPTCEditDialog(QWidget* parent, KURL::List urls, KIPI::Interface
     // About data and help button.
 
     d->about = new KIPIPlugins::KPAboutData(I18N_NOOP("Edit Metadata"),
-                                            NULL,
+                                            0,
                                             KAboutData::License_GPL,
-                                            I18N_NOOP("A Plugin to edit pictures metadata"),
-                                            "(c) 2006-2007, Gilles Caulier");
+                                            I18N_NOOP("A Plugin to edit image metadata"),
+                                            "(c) 2006-2008, Gilles Caulier");
 
     d->about->addAuthor("Gilles Caulier", I18N_NOOP("Author and Maintainer"),
                         "caulier dot gilles at gmail dot com");
 
     KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Edit Metadata Handbook"),
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"),
                                  this, SLOT(slotHelp()), 0, -1, 0);
     actionButton(Help)->setPopup( helpMenu->menu() );
 
