@@ -1,15 +1,17 @@
 /* ============================================================
- * Authors     : Gilles Caulier
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
  * Date        : 2006-10-15
  * Description : IPTC keywords settings page.
- * 
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,6 +35,8 @@
 #include <kdialog.h>
 #include <klistbox.h>
 #include <klineedit.h>
+#include <kactivelabel.h>
+#include <kiconloader.h>
 
 // LibKExiv2 includes. 
 
@@ -97,6 +101,8 @@ IPTCKeywords::IPTCKeywords(QWidget* parent)
     
     d->addKeywordButton = new QPushButton( i18n("&Add"), parent);
     d->delKeywordButton = new QPushButton( i18n("&Delete"), parent);
+    d->addKeywordButton->setIconSet(SmallIcon("add"));
+    d->delKeywordButton->setIconSet(SmallIcon("remove"));
     d->delKeywordButton->setEnabled(false);
 
     grid->addMultiCellWidget(d->keywordsCheck, 0, 0, 0, 1);
@@ -107,9 +113,15 @@ IPTCKeywords::IPTCKeywords(QWidget* parent)
 
     // --------------------------------------------------------
 
-    QLabel *iptcNote = new QLabel(i18n("<b>Note: IPTC text tags only support printable "
-                                       "ASCII characters set.</b>"), parent);
-    grid->addMultiCellWidget(iptcNote, 4, 4, 1, 1);
+    KActiveLabel *note = new KActiveLabel(i18n("<b>Note: "
+                 "<b><a href='http://en.wikipedia.org/wiki/IPTC'>IPTC</a></b> "
+                 "text tags only support the printable "
+                 "<b><a href='http://en.wikipedia.org/wiki/Ascii'>ASCII</a></b> "
+                 "characters set and limit strings size. "
+                 "Use contextual help for details.</b>"), parent);
+    note->setMaximumWidth(150);
+
+    grid->addMultiCellWidget(note, 4, 4, 1, 1);
     grid->setColStretch(0, 10);                     
     grid->setRowStretch(5, 10);      
                                          
