@@ -1,22 +1,24 @@
 /* ============================================================
- * File  : simpleviewerexport.h
- * Author: Joern Ahrens <joern.ahrens@kdemail.net>
- * Date  : 2005-12-19
- * Description :
  *
- * Copyright 2005-2006 by Joern Ahrens <joern.ahrens@kdemail.net>
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2005-12-19
+ * Description : a plugin to export image collections using SimpleViewer.
+ *
+ * Copyright (C) 2005-2006 by Joern Ahrens <joern dot ahrens at kdemail dot net>
+ * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 #ifndef SIMPLEVIEWEREXPORT_H
@@ -25,24 +27,26 @@
 // QT includes
 
 #include <qobject.h>
+#include <qdom.h>
 
 // KIPI includes
 
 #include <libkipi/interface.h>
 
+class QTimer;
+class QString;
+class QImage;
+
+class KZip;
+class KURL;
+class KArchiveEntry;
+class KTempDir;
+
 namespace KIPI
 {
     class BatchProgressDialog;
 }
 
-class QTimer;
-class KZip;
-class KURL;
-class QString;
-class QImage;
-class KArchiveEntry;
-class KTempDir;
-
 namespace KIPISimpleViewerExportPlugin
 {
 
@@ -56,7 +60,7 @@ class SimpleViewerExport : public QObject
 public:
 
     static void run( KIPI::Interface* interface, QObject *parent=0 );
- 
+
 private:
 
     SimpleViewerExport( KIPI::Interface* interface, QObject *parent=0 );
@@ -99,38 +103,32 @@ private:
      */
     bool resizeImage(const QImage &image, int maxSize, QImage &resized);
 
-    /**
-     * Creates the header of the simpleviewer config file
-     */
-    void cfgCreateHeader(QTextStream &ts);
-
     /**
      * Adds an image to the simpleviewer config file
      *
-     * @param kurl path to the images
+     * @param xmlDoc main XML document
+     * @param galleryElem gallery XML element
+     * @param url path to original image
+     * @param newName new image file name used by gallery
      */
-    void cfgAddImage(QTextStream &ts, const KURL &kurl);
+    void cfgAddImage(QDomDocument &xmlDoc, QDomElement &galleryElem, 
+                     const KURL &url, const QString& newName);
 
-    /**
-     * Finishes the simpleviewer config file
-     */
-    void cfgCreateFooter(QTextStream &ts);
-    
     /**
      * Creates the index.html file
      */
     bool createIndex();
-    
+
     /**
      * Copies simpleviewers files into the export directory
      */
     bool copySimpleViewer();
-    
+
     /**
      * Is the SimpleViewer flash installed?
      */
     bool checkSimpleViewer() const;
-    
+
     /**
      * Installs the SimpleViewer files for the later export 
      * on the users machine
@@ -138,38 +136,40 @@ private:
     bool installSimpleViewer();
 
     bool upload();
-    
+
     bool unzip(const QString &url);
 
     bool openArchive(KZip &zip);
-    
+
     bool extractArchive(KZip &zip);
-    
+
     bool extractFile(const KArchiveEntry *entry);
-    
+
 public slots:
-    
+
     void slotProcess();
     void slotCancel();
-    
+
 private:
-    
-    SVEDialog                           *m_configDlg;
-    KIPI::Interface                     *m_interface;
-    KIPI::BatchProgressDialog           *m_progressDlg;
-    QValueList<KIPI::ImageCollection>    m_albumsList;
-    QTimer                              *m_timer;
+
     int                                  m_totalActions;
     int                                  m_action;
     bool                                 m_canceled;
+
+    QTimer                              *m_timer;
     QString                              m_dataLocal;
     QStringList                          m_simpleViewerFiles;
     QString                              m_hostName;
     QString                              m_hostURL;
+
     KTempDir                            *m_tempDir;
+
+    SVEDialog                           *m_configDlg;
+    KIPI::Interface                     *m_interface;
+    KIPI::BatchProgressDialog           *m_progressDlg;
+    QValueList<KIPI::ImageCollection>    m_albumsList;
 };
 
-}
+} // namespace KIPISimpleViewerExportPlugin
 
 #endif /* SIMPLEVIEWEREXPORT_H */
-
