@@ -1,23 +1,24 @@
 /* ============================================================
- * Authors: Jesper K. Pedersen <blackie@kde.org>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2004-05-16
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-05-16
  * Description : a plugin to set time stamp of picture files.
  *
- * Copyright 2003-2005 by Jesper Pedersen
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2003-2005 by Jesper Pedersen <blackie@kde.org>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 #ifndef TIMEADJUSTDIALOG_H
@@ -53,17 +54,18 @@ public:
     
     void setImages(const KURL::List& images);
 
-protected slots:
+protected:
+
+    void closeEvent(QCloseEvent *);
+
+private slots:
 
     void slotUpdateExample();
     void slotAdjustmentTypeChanged();
     void slotOk();
     void slotCancel();
     void slotHelp();
-
-protected:
-
-    void closeEvent(QCloseEvent *);
+    void slotResetDateToCurrent();
 
 private:
 
@@ -74,7 +76,6 @@ private:
 private:
 
     TimeAdjustDialogPrivate *d;
-
 };
 
 }  // NameSpace KIPITimeAdjustPlugin
